@@ -2,10 +2,10 @@ from pprint import pprint
 
 from matplotlib import pyplot as plt
 
-from examples.datasets.linear import LinearRegressionDataset
-from pytolemaic.pytrust import PyTrust
-from pytolemaic.utils.dmd import DMD
-from pytolemaic.utils.metrics import Metrics
+from pytolemaic import DMD
+from pytolemaic import Metrics
+from pytolemaic import PyTrust
+from resources.datasets.linear import LinearRegressionDataset
 
 
 def run():
@@ -43,7 +43,7 @@ def run():
         metric=metric,
         splitter=splitter)
 
-    sensitivity_report = pytrust.create_sensitivity_report()
+    sensitivity_report = pytrust.sensitivity_report
     pprint(sensitivity_report.to_dict(printable=True), width=120)
     pprint(sensitivity_report.to_dict_meaning(), width=120)
 
